ChatCompletionMessageFunctionCall class

The name and arguments of a function that should be called, as generated by the model.

Annotations
  • @freezed

Constructors

ChatCompletionMessageFunctionCall({required String name, required String arguments})
Factory constructor for ChatCompletionMessageFunctionCall
const
factory
ChatCompletionMessageFunctionCall.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

arguments String
The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.
no setterinherited
copyWith → $ChatCompletionMessageFunctionCallCopyWith<ChatCompletionMessageFunctionCall>
Create a copy of ChatCompletionMessageFunctionCall with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the function to call.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ChatCompletionMessageFunctionCall to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema