ChatCompletionMessageToolCalls typedef
The tool calls generated by the model, such as function calls.
Implementation
typedef ChatCompletionMessageToolCalls = List<ChatCompletionMessageToolCall>;
The tool calls generated by the model, such as function calls.
typedef ChatCompletionMessageToolCalls = List<ChatCompletionMessageToolCall>;