index property
The index of the choice in the list of choices.
Implementation
@JsonKey(includeIfNull: false)
int? get index => throw _privateConstructorUsedError;
The index of the choice in the list of choices.
@JsonKey(includeIfNull: false)
int? get index => throw _privateConstructorUsedError;