CreateThreadAndRunRequest class

Request object for the Create thread and run endpoint.

Annotations
  • @freezed

Constructors

CreateThreadAndRunRequest({@JsonKey.new(name: 'assistant_id') required String assistantId, @JsonKey.new(includeIfNull: false) CreateThreadRequest? thread, @JsonKey.new(includeIfNull: false) ThreadAndRunModel? model, @JsonKey.new(includeIfNull: false) String? instructions, @JsonKey.new(includeIfNull: false) List<AssistantTools>? tools, @JsonKey.new(name: 'tool_resources', includeIfNull: false) ToolResources? toolResources, @JsonKey.new(includeIfNull: false) Map<String, dynamic>? metadata, @JsonKey.new(includeIfNull: false) @Default.new(1.0) double? temperature, @JsonKey.new(name: 'top_p', includeIfNull: false) @Default.new(1.0) double? topP, @JsonKey.new(name: 'max_prompt_tokens', includeIfNull: false) int? maxPromptTokens, @JsonKey.new(name: 'max_completion_tokens', includeIfNull: false) int? maxCompletionTokens, @JsonKey.new(name: 'truncation_strategy', includeIfNull: false) TruncationObject? truncationStrategy, @JsonKey.new(name: 'tool_choice', includeIfNull: false) CreateThreadAndRunRequestToolChoice? toolChoice, @JsonKey.new(name: 'parallel_tool_calls', includeIfNull: false) bool? parallelToolCalls, @JsonKey.new(name: 'response_format', includeIfNull: false) CreateThreadAndRunRequestResponseFormat? responseFormat, @JsonKey.new(includeIfNull: false) bool? stream})
Factory constructor for CreateThreadAndRunRequest
const
factory
CreateThreadAndRunRequest.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

assistantId String
The ID of the assistant to use to execute this run.
no setterinherited
copyWith → $CreateThreadAndRunRequestCopyWith<CreateThreadAndRunRequest>
Create a copy of CreateThreadAndRunRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
instructions String?
Override the default system message of the assistant. This is useful for modifying the behavior on a per-run basis.
no setterinherited
maxCompletionTokens int?
The maximum number of completion tokens that may be used over the course of the run. The run will make a best effort to use only the number of completion tokens specified, across multiple turns of the run. If the run exceeds the number of completion tokens specified, the run will end with status incomplete. See incomplete_details for more info.
no setterinherited
maxPromptTokens int?
The maximum number of prompt tokens that may be used over the course of the run. The run will make a best effort to use only the number of prompt tokens specified, across multiple turns of the run. If the run exceeds the number of prompt tokens specified, the run will end with status incomplete. See incomplete_details for more info.
no setterinherited
metadata Map<String, dynamic>?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format. Keys can be a maximum of 64 characters long and values can be a maximum of 512 characters long.
no setterinherited
model ThreadAndRunModel?
The ID of the Model to be used to execute this run. If a value is provided here, it will override the model associated with the assistant. If not, the model associated with the assistant will be used.
no setterinherited
parallelToolCalls bool?
Whether to enable parallel function calling during tool use.
no setterinherited
responseFormat CreateThreadAndRunRequestResponseFormat?
Specifies the format that the model must output. Compatible with GPT-4o, GPT-4 Turbo, and all GPT-3.5 Turbo models since gpt-3.5-turbo-1106.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream bool?
If true, returns a stream of events that happen during the Run as server-sent events, terminating when the Run enters a terminal state with a data: [DONE] message.
no setterinherited
temperature double?
What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.
no setterinherited
thread CreateThreadRequest?
If no thread is provided, an empty thread will be created.
no setterinherited
toolChoice CreateThreadAndRunRequestToolChoice?
Controls which (if any) tool is called by the model. none means the model will not call any tools and instead generates a message. auto is the default value and means the model can pick between generating a message or calling one or more tools. required means the model must call one or more tools before responding to the user. Specifying a particular tool like {"type": "file_search"} or {"type": "function", "function": {"name": "my_function"}} forces the model to call that tool.
no setterinherited
toolResources ToolResources?
A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.
no setterinherited
tools List<AssistantTools>?
Override the tools the assistant can use for this run. This is useful for modifying the behavior on a per-run basis.
no setterinherited
topP double?
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered.
no setterinherited
truncationStrategy TruncationObject?
Controls for how a thread will be truncated prior to the run. Use this to control the intial context window of the run.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CreateThreadAndRunRequest to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

maxCompletionTokensMinValue → const int
maxPromptTokensMinValue → const int
propertyNames → const List<String>
List of all property names of schema
temperatureDefaultValue → const double
Validation constants
temperatureMaxValue → const double
temperatureMinValue → const double
topPDefaultValue → const double
topPMaxValue → const double
topPMinValue → const double