instructions property
Override the default system message of the assistant. This is useful for modifying the behavior on a per-run basis.
Implementation
@JsonKey(includeIfNull: false)
String? get instructions => throw _privateConstructorUsedError;
Override the default system message of the assistant. This is useful for modifying the behavior on a per-run basis.
@JsonKey(includeIfNull: false)
String? get instructions => throw _privateConstructorUsedError;