FineTuningJob class

The fine_tuning.job object represents a fine-tuning job that has been created through the API.

Annotations
  • @freezed

Constructors

FineTuningJob({required String id, @JsonKey.new(name: 'created_at') required int createdAt, required FineTuningJobError? error, @JsonKey.new(name: 'fine_tuned_model') required String? fineTunedModel, @JsonKey.new(name: 'finished_at') required int? finishedAt, required FineTuningJobHyperparameters hyperparameters, required String model, required FineTuningJobObject object, @JsonKey.new(name: 'organization_id') required String organizationId, @JsonKey.new(name: 'result_files') required List<String> resultFiles, required FineTuningJobStatus status, @JsonKey.new(name: 'trained_tokens') required int? trainedTokens, @JsonKey.new(name: 'training_file') required String trainingFile, @JsonKey.new(name: 'validation_file') required String? validationFile, @JsonKey.new(includeIfNull: false) List<FineTuningIntegration>? integrations})
Factory constructor for FineTuningJob
const
factory
FineTuningJob.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $FineTuningJobCopyWith<FineTuningJob>
Create a copy of FineTuningJob with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt int
The Unix timestamp (in seconds) for when the fine-tuning job was created.
no setterinherited
error FineTuningJobError?
For fine-tuning jobs that have failed, this will contain more information on the cause of the failure.
no setterinherited
fineTunedModel String?
The name of the fine-tuned model that is being created. The value will be null if the fine-tuning job is still running.
no setterinherited
finishedAt int?
The Unix timestamp (in seconds) for when the fine-tuning job was finished. The value will be null if the fine-tuning job is still running.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hyperparameters FineTuningJobHyperparameters
The hyperparameters used for the fine-tuning job. See the fine-tuning guide for more details.
no setterinherited
id String
The object identifier, which can be referenced in the API endpoints.
no setterinherited
integrations List<FineTuningIntegration>?
A list of integrations to enable for this fine-tuning job.
no setterinherited
model String
The base model that is being fine-tuned.
no setterinherited
object FineTuningJobObject
The object type, which is always "fine_tuning.job".
no setterinherited
organizationId String
The organization that owns the fine-tuning job.
no setterinherited
resultFiles List<String>
The compiled results file ID(s) for the fine-tuning job. You can retrieve the results with the Files API.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status FineTuningJobStatus
The current status of the fine-tuning job, which can be either validating_files, queued, running, succeeded, failed, or cancelled.
no setterinherited
trainedTokens int?
The total number of billable tokens processed by this fine-tuning job. The value will be null if the fine-tuning job is still running.
no setterinherited
trainingFile String
The file ID used for training. You can retrieve the training data with the Files API.
no setterinherited
validationFile String?
The file ID used for validation. You can retrieve the validation results with the Files API.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FineTuningJob to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema