ListRunsResponse class

Represents a list of runs returned by the List runs endpoint.

Annotations
  • @freezed

Constructors

ListRunsResponse({required String object, required List<RunObject> data, @JsonKey.new(name: 'first_id', includeIfNull: false) String? firstId, @JsonKey.new(name: 'last_id', includeIfNull: false) String? lastId, @JsonKey.new(name: 'has_more') required bool hasMore})
Factory constructor for ListRunsResponse
const
factory
ListRunsResponse.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $ListRunsResponseCopyWith<ListRunsResponse>
Create a copy of ListRunsResponse with the given fields replaced by the non-null parameter values.
no setterinherited
data List<RunObject>
The list of runs.
no setterinherited
firstId String?
The ID of the first run in the list.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
Whether there are more runs to retrieve.
no setterinherited
lastId String?
The ID of the last run in the list.
no setterinherited
object String
The object type, which is always list.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ListRunsResponse to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema