MessageContentText class

The text content that is part of a message.

Annotations
  • @freezed

Constructors

MessageContentText({required String value, @JsonKey.new(includeIfNull: false) List<MessageContentTextAnnotations>? annotations})
Factory constructor for MessageContentText
const
factory
MessageContentText.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

annotations List<MessageContentTextAnnotations>?
A list of annotations that point to specific quotes from specific files.
no setterinherited
copyWith → $MessageContentTextCopyWith<MessageContentText>
Create a copy of MessageContentText with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The data that makes up the text.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this MessageContentText to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema