MessageDeltaContentTextAnnotationsFileCitation class

A citation within the message that points to a specific quote from a specific File associated with the assistant or the message.

Annotations
  • @freezed

Constructors

MessageDeltaContentTextAnnotationsFileCitation({@JsonKey.new(name: 'file_id', includeIfNull: false) String? fileId, @JsonKey.new(includeIfNull: false) String? quote})
Factory constructor for MessageDeltaContentTextAnnotationsFileCitation
const
factory
MessageDeltaContentTextAnnotationsFileCitation.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $MessageDeltaContentTextAnnotationsFileCitationCopyWith<MessageDeltaContentTextAnnotationsFileCitation>
Create a copy of MessageDeltaContentTextAnnotationsFileCitation with the given fields replaced by the non-null parameter values.
no setterinherited
fileId String?
The ID of the specific File the citation is from.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
quote String?
The specific quote in the file.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this MessageDeltaContentTextAnnotationsFileCitation to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema