categoryScores property
A list of the categories along with their scores as predicted by model.
Implementation
@JsonKey(name: 'category_scores')
ModerationCategoriesScores get categoryScores =>
throw _privateConstructorUsedError;
A list of the categories along with their scores as predicted by model.
@JsonKey(name: 'category_scores')
ModerationCategoriesScores get categoryScores =>
throw _privateConstructorUsedError;