RunCompletionUsage class

Usage statistics related to the run. This value will be null if the run is not in a terminal state (i.e. in_progress, queued, etc.).

Annotations
  • @freezed

Constructors

RunCompletionUsage({@JsonKey.new(name: 'completion_tokens') required int completionTokens, @JsonKey.new(name: 'prompt_tokens') required int promptTokens, @JsonKey.new(name: 'total_tokens') required int totalTokens})
Factory constructor for RunCompletionUsage
const
factory
RunCompletionUsage.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

completionTokens int
Number of completion tokens used over the course of the run.
no setterinherited
copyWith → $RunCompletionUsageCopyWith<RunCompletionUsage>
Create a copy of RunCompletionUsage with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
promptTokens int
Number of prompt tokens used over the course of the run.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTokens int
Total number of tokens used (prompt + completion).
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RunCompletionUsage to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema