RunStepDeltaStepDetailsToolCalls class sealed

Tool calls the run step was involved in.

Annotations
  • @Freezed.new(unionKey: 'type', unionValueCase: FreezedUnionCase.snake)

Constructors

RunStepDeltaStepDetailsToolCalls.codeInterpreter({required int index, @JsonKey.new(includeIfNull: false) String? id, required String type, @JsonKey.new(name: 'code_interpreter', includeIfNull: false) RunStepDeltaStepDetailsToolCallsCodeObjectCodeInterpreter? codeInterpreter})
Details of the Code Interpreter tool call the run step was involved in.
const
factory
RunStepDeltaStepDetailsToolCalls.fileSearch({required int index, @JsonKey.new(includeIfNull: false) String? id, required String type, @JsonKey.new(name: 'file_search') required Map<String, dynamic> fileSearch})
File search tool call
const
factory
RunStepDeltaStepDetailsToolCalls.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory
RunStepDeltaStepDetailsToolCalls.function({required int index, @JsonKey.new(includeIfNull: false) String? id, required String type, @JsonKey.new(includeIfNull: false) RunStepDeltaStepDetailsToolCallsFunction? function})
Function tool call
const
factory

Properties

copyWith → $RunStepDeltaStepDetailsToolCallsCopyWith<RunStepDeltaStepDetailsToolCalls>
Create a copy of RunStepDeltaStepDetailsToolCalls with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of the tool call.
no setterinherited
index int
The index of the tool call in the tool calls array.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Always code_interpreter.
no setterinherited

Methods

map<TResult extends Object?>({required TResult codeInterpreter(RunStepDeltaStepDetailsToolCallsCodeObject value), required TResult fileSearch(RunStepDeltaStepDetailsToolCallsFileSearchObject value), required TResult function(RunStepDeltaStepDetailsToolCallsFunctionObject value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? codeInterpreter(RunStepDeltaStepDetailsToolCallsCodeObject value)?, TResult? fileSearch(RunStepDeltaStepDetailsToolCallsFileSearchObject value)?, TResult? function(RunStepDeltaStepDetailsToolCallsFunctionObject value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult codeInterpreter(RunStepDeltaStepDetailsToolCallsCodeObject value)?, TResult fileSearch(RunStepDeltaStepDetailsToolCallsFileSearchObject value)?, TResult function(RunStepDeltaStepDetailsToolCallsFunctionObject value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult codeInterpreter(int index, String? id, String type, RunStepDeltaStepDetailsToolCallsCodeObjectCodeInterpreter? codeInterpreter)?, TResult fileSearch(int index, String? id, String type, Map<String, dynamic> fileSearch)?, TResult function(int index, String? id, String type, RunStepDeltaStepDetailsToolCallsFunction? function)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RunStepDeltaStepDetailsToolCalls to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult codeInterpreter(int index, String? id, String type, RunStepDeltaStepDetailsToolCallsCodeObjectCodeInterpreter? codeInterpreter), required TResult fileSearch(int index, String? id, String type, Map<String, dynamic> fileSearch), required TResult function(int index, String? id, String type, RunStepDeltaStepDetailsToolCallsFunction? function)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? codeInterpreter(int index, String? id, String type, RunStepDeltaStepDetailsToolCallsCodeObjectCodeInterpreter? codeInterpreter)?, TResult? fileSearch(int index, String? id, String type, Map<String, dynamic> fileSearch)?, TResult? function(int index, String? id, String type, RunStepDeltaStepDetailsToolCallsFunction? function)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited