RunStepDetailsMessageCreation class

Details of the message creation by the run step.

Annotations
  • @freezed

Constructors

RunStepDetailsMessageCreation({@JsonKey.new(name: 'message_id') required String messageId})
Factory constructor for RunStepDetailsMessageCreation
const
factory
RunStepDetailsMessageCreation.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $RunStepDetailsMessageCreationCopyWith<RunStepDetailsMessageCreation>
Create a copy of RunStepDetailsMessageCreation with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
messageId String
The ID of the message that was created by this run step.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RunStepDetailsMessageCreation to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema