RunStepDetailsToolCalls class sealed

Tool calls the run step was involved in.

Annotations
  • @Freezed.new(unionKey: 'type', unionValueCase: FreezedUnionCase.snake)

Constructors

RunStepDetailsToolCalls.codeInterpreter({required String id, required String type, @JsonKey.new(name: 'code_interpreter') required RunStepDetailsToolCallsCodeObjectCodeInterpreter codeInterpreter})
Details of the Code Interpreter tool call the run step was involved in.
const
factory
RunStepDetailsToolCalls.fileSearch({required String id, required String type, @JsonKey.new(name: 'file_search') required RunStepDetailsToolCallsFileSearch fileSearch})
File search tool call
const
factory
RunStepDetailsToolCalls.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory
RunStepDetailsToolCalls.function({required String id, required String type, required RunStepDetailsToolCallsFunction function})
Function tool call
const
factory

Properties

copyWith → $RunStepDetailsToolCallsCopyWith<RunStepDetailsToolCalls>
Create a copy of RunStepDetailsToolCalls with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
The ID of the tool call.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Always code_interpreter.
no setterinherited

Methods

map<TResult extends Object?>({required TResult codeInterpreter(RunStepDetailsToolCallsCodeObject value), required TResult fileSearch(RunStepDetailsToolCallsFileSearchObject value), required TResult function(RunStepDetailsToolCallsFunctionObject value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? codeInterpreter(RunStepDetailsToolCallsCodeObject value)?, TResult? fileSearch(RunStepDetailsToolCallsFileSearchObject value)?, TResult? function(RunStepDetailsToolCallsFunctionObject value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult codeInterpreter(RunStepDetailsToolCallsCodeObject value)?, TResult fileSearch(RunStepDetailsToolCallsFileSearchObject value)?, TResult function(RunStepDetailsToolCallsFunctionObject value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult codeInterpreter(String id, String type, RunStepDetailsToolCallsCodeObjectCodeInterpreter codeInterpreter)?, TResult fileSearch(String id, String type, RunStepDetailsToolCallsFileSearch fileSearch)?, TResult function(String id, String type, RunStepDetailsToolCallsFunction function)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RunStepDetailsToolCalls to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult codeInterpreter(String id, String type, RunStepDetailsToolCallsCodeObjectCodeInterpreter codeInterpreter), required TResult fileSearch(String id, String type, RunStepDetailsToolCallsFileSearch fileSearch), required TResult function(String id, String type, RunStepDetailsToolCallsFunction function)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? codeInterpreter(String id, String type, RunStepDetailsToolCallsCodeObjectCodeInterpreter codeInterpreter)?, TResult? fileSearch(String id, String type, RunStepDetailsToolCallsFileSearch fileSearch)?, TResult? function(String id, String type, RunStepDetailsToolCallsFunction function)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited