RunStepDetailsToolCallsCodeObjectCodeInterpreter class
The Code Interpreter tool call definition.
- Annotations
-
- @freezed
Constructors
-
RunStepDetailsToolCallsCodeObjectCodeInterpreter({required String input, required List<
RunStepDetailsToolCallsCodeOutput> outputs}) -
Factory constructor for RunStepDetailsToolCallsCodeObjectCodeInterpreter
constfactory
-
RunStepDetailsToolCallsCodeObjectCodeInterpreter.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $RunStepDetailsToolCallsCodeObjectCodeInterpreterCopyWith<
RunStepDetailsToolCallsCodeObjectCodeInterpreter> -
Create a copy of RunStepDetailsToolCallsCodeObjectCodeInterpreter
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → String
-
The input to the Code Interpreter tool call.
no setterinherited
-
outputs
→ List<
RunStepDetailsToolCallsCodeOutput> -
The outputs from the Code Interpreter tool call. Code Interpreter can output one or more items, including text (
logs) or images (image). Each of these are represented by a different object type.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this RunStepDetailsToolCallsCodeObjectCodeInterpreter to a JSON map.
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema