outputs property

List<RunStepDetailsToolCallsCodeOutput> get outputs
inherited

The outputs from the Code Interpreter tool call. Code Interpreter can output one or more items, including text (logs) or images (image). Each of these are represented by a different object type.

Implementation

List<RunStepDetailsToolCallsCodeOutput> get outputs =>
    throw _privateConstructorUsedError;