ChatCompletionStreamMessageToolCallChunk class
The tool that should be called, as generated by the model.
- Annotations
-
- @freezed
Constructors
- ChatCompletionStreamMessageToolCallChunk({required int index, @JsonKey.new(includeIfNull: false) String? id, @JsonKey.new(includeIfNull: false, unknownEnumValue: JsonKey.nullForUndefinedEnumValue) ChatCompletionStreamMessageToolCallChunkType? type, @JsonKey.new(includeIfNull: false) ChatCompletionStreamMessageFunctionCall? function})
-
Factory constructor for ChatCompletionStreamMessageToolCallChunk
constfactory
-
ChatCompletionStreamMessageToolCallChunk.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $ChatCompletionStreamMessageToolCallChunkCopyWith<
ChatCompletionStreamMessageToolCallChunk> -
Create a copy of ChatCompletionStreamMessageToolCallChunk
with the given fields replaced by the non-null parameter values.
no setterinherited
- function → ChatCompletionStreamMessageFunctionCall?
-
The name and arguments of a function that should be called, as generated by the model.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The ID of the tool call.
no setterinherited
- index → int
-
No Description
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ChatCompletionStreamMessageToolCallChunkType?
-
The type of the tool. Currently, only
functionis supported.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ChatCompletionStreamMessageToolCallChunk to a JSON map.
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema