CreateVectorStoreFileBatchRequest class
Request object for the Create vector store file batch endpoint.
- Annotations
-
- @freezed
Constructors
-
CreateVectorStoreFileBatchRequest({@JsonKey.new(name: 'file_ids') required List<
String> fileIds, @JsonKey.new(name: 'chunking_strategy', includeIfNull: false) ChunkingStrategyRequestParam? chunkingStrategy}) -
Factory constructor for CreateVectorStoreFileBatchRequest
constfactory
-
CreateVectorStoreFileBatchRequest.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
- chunkingStrategy → ChunkingStrategyRequestParam?
-
The chunking strategy used to chunk the file(s). If not set, will use the
autostrategy. Any of: AutoChunkingStrategyRequestParam, StaticChunkingStrategyRequestParamno setterinherited -
copyWith
→ $CreateVectorStoreFileBatchRequestCopyWith<
CreateVectorStoreFileBatchRequest> -
Create a copy of CreateVectorStoreFileBatchRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
-
fileIds
→ List<
String> -
A list of File IDs that the vector store should use. Useful for tools like
file_searchthat can access files.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CreateVectorStoreFileBatchRequest to a JSON map.
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema