FineTuningJobCheckpoint class
The fine_tuning.job.checkpoint object represents a model checkpoint for a fine-tuning job that is ready to use.
- Annotations
-
- @freezed
Constructors
- FineTuningJobCheckpoint({required String id, @JsonKey.new(name: 'created_at') required int createdAt, @JsonKey.new(name: 'fine_tuned_model_checkpoint') required String fineTunedModelCheckpoint, @JsonKey.new(name: 'step_number') required int stepNumber, required FineTuningJobCheckpointMetrics metrics, @JsonKey.new(name: 'fine_tuning_job_id') required String fineTuningJobId, required FineTuningJobCheckpointObject object})
-
Factory constructor for FineTuningJobCheckpoint
constfactory
-
FineTuningJobCheckpoint.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $FineTuningJobCheckpointCopyWith<
FineTuningJobCheckpoint> -
Create a copy of FineTuningJobCheckpoint
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → int
-
The Unix timestamp (in seconds) for when the checkpoint was created.
no setterinherited
- fineTunedModelCheckpoint → String
-
The name of the fine-tuned checkpoint model that is created.
no setterinherited
- fineTuningJobId → String
-
The name of the fine-tuning job that this checkpoint was created from.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The checkpoint identifier, which can be referenced in the API endpoints.
no setterinherited
- metrics → FineTuningJobCheckpointMetrics
-
Metrics at the step number during the fine-tuning job.
no setterinherited
- object → FineTuningJobCheckpointObject
-
The object type, which is always "fine_tuning.job.checkpoint".
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepNumber → int
-
The step number that the checkpoint was created at.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this FineTuningJobCheckpoint to a JSON map.
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema