FunctionParameters typedef
The parameters the functions accepts, described as a JSON Schema object. See the guide for examples, and the JSON Schema reference for documentation about the format.
Omitting parameters defines a function with an empty parameter list.
Implementation
typedef FunctionParameters = Map<String, dynamic>;