RunStepDetailsToolCallsCodeOutputImageObject class
abstract
Properties
-
copyWith
→ _$$RunStepDetailsToolCallsCodeOutputImageObjectImplCopyWith<_$RunStepDetailsToolCallsCodeOutputImageObjectImpl>
-
Create a copy of RunStepDetailsToolCallsCodeOutput
with the given fields replaced by the non-null parameter values.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
image
→ RunStepDetailsToolCallsCodeOutputImage
-
Code interpreter image output.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ String
-
Always
image.
no setter
Methods
-
map<TResult extends Object?>({required TResult logs(RunStepDetailsToolCallsCodeOutputLogsObject value), required TResult image(RunStepDetailsToolCallsCodeOutputImageObject value)})
→ TResult
-
inherited
-
mapOrNull<TResult extends Object?>({TResult? logs(RunStepDetailsToolCallsCodeOutputLogsObject value)?, TResult? image(RunStepDetailsToolCallsCodeOutputImageObject value)?})
→ TResult?
-
inherited
-
maybeMap<TResult extends Object?>({TResult logs(RunStepDetailsToolCallsCodeOutputLogsObject value)?, TResult image(RunStepDetailsToolCallsCodeOutputImageObject value)?, required TResult orElse()})
→ TResult
-
inherited
-
maybeWhen<TResult extends Object?>({TResult logs(String type, String logs)?, TResult image(String type, RunStepDetailsToolCallsCodeOutputImage image)?, required TResult orElse()})
→ TResult
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this RunStepDetailsToolCallsCodeOutput to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
when<TResult extends Object?>({required TResult logs(String type, String logs), required TResult image(String type, RunStepDetailsToolCallsCodeOutputImage image)})
→ TResult
-
inherited
-
whenOrNull<TResult extends Object?>({TResult? logs(String type, String logs)?, TResult? image(String type, RunStepDetailsToolCallsCodeOutputImage image)?})
→ TResult?
-
inherited