SubmitToolOutputsRunRequest class
Request object for the Submit tool outputs to run endpoint.
- Annotations
-
- @freezed
Constructors
-
SubmitToolOutputsRunRequest({@JsonKey.new(name: 'tool_outputs') required List<
RunSubmitToolOutput> toolOutputs, @JsonKey.new(includeIfNull: false) bool? stream}) -
Factory constructor for SubmitToolOutputsRunRequest
constfactory
-
SubmitToolOutputsRunRequest.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $SubmitToolOutputsRunRequestCopyWith<
SubmitToolOutputsRunRequest> -
Create a copy of SubmitToolOutputsRunRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stream → bool?
-
If
true, returns a stream of events that happen during the Run as server-sent events, terminating when the Run enters a terminal state with adata: [DONE]message.no setterinherited -
toolOutputs
→ List<
RunSubmitToolOutput> -
A list of tools for which the outputs are being submitted.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this SubmitToolOutputsRunRequest to a JSON map.
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema